@@ -30,12 +30,15 @@ def OpenSession(cred_path: str, region: str = 'us-east-2'):
     :param region:
     :return:
     """
-    cred = OpenCredentials(cred_path)
-    return boto3.session.Session(
-        aws_access_key_id=cred['Access key ID'],
-        aws_secret_access_key=cred['Secret access key'],
-        region_name=region
-    )
+    if cred_path:
+        cred = OpenCredentials(cred_path)
+        return boto3.session.Session(
+            aws_access_key_id=cred['Access key ID'],
+            aws_secret_access_key=cred['Secret access key'],
+            region_name=region
+        )
+    else:
+        return boto3.session.Session()
 
 
 def OpenEC2Client(cred_path: str, region: str = 'us-east-2'):
